# Generated by Django 4.2.6 on 2023-10-09 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bot',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('t_id', models.CharField(default='', max_length=100, verbose_name='Telegram ID')),
                ('token', models.CharField(blank=True, max_length=255, null=True, verbose_name='Bot token')),
                ('name', models.CharField(default='', max_length=250, verbose_name='Name')),
                ('username', models.CharField(default='', max_length=250, verbose_name='Username')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creation date')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
